@@ -7,43 +7,69 @@ from twisted.internet.defer import succeed, fail
 from twisted.internet.threads import deferToThreadPool
 from twisted.python.filepath import FilePath
 from twisted.python.threadpool import ThreadPool
-from twisted.trial.unittest import SkipTest
 
 from txspore import client
 from txspore import model
 from txspore import util
-from txspore.client import getXMLForREST
+from txspore.client import AsyncClient
 from txspore.testing import payload
 from txspore.testing.base import TXSporeTestCase
 
 
-class ClientTestCase(TXSporeTestCase):
+class CacheTestCase(TXSporeTestCase):
 
-    def test_openURL(self):
-        self.addCleanup(setattr, client, "getPage", client.getPage)
-        client.getPage = lambda url: succeed(payload.sampleLargeCardResponse)
+    def test_creation(self):
+        cache = client.Cache()
+        self.assertEquals(cache._cache, {})
 
-        d = client.openURL("http://some.spore.url")
-        d.addCallback(
-            self.assertEquals, "\nsampleLargeCardResponse BINARY DATA")
-        return d
+    def test_set(self):
+        cache = client.Cache()
+        cache.set("mykey", "myvalue")
+        self.assertEquals(cache._cache["mykey"], "myvalue")
 
-    def test_openURLWithError(self):
-        self.addCleanup(setattr, client, "getPage", client.getPage)
-        client.getPage = lambda url: fail(ValueError("oops"))
+    def test_get(self):
+        cache = client.Cache()
+        self.assertEquals(cache.get("mykey"), None)
+        cache.set("mykey", "myvalue")
+        self.assertEquals(cache.get("mykey"), "myvalue")
 
-        d = client.openURL("http://some.spore.url")
-        self.assertFailure(d, ValueError)
-        logged = self.catcher.pop()
-        self.assertEquals(logged["message"][0], "ERROR: oops")
+    def test_remove(self):
+        cache = client.Cache()
+        cache.set("mykey1", "myvalue1")
+        cache.set("mykey2", "myvalue2")
+        self.assertEquals(cache.get("mykey1"), "myvalue1")
+        self.assertEquals(cache.get("mykey2"), "myvalue2")
+        cache.remove("mykey1")
+        self.assertEquals(cache.get("mykey1"), None)
+        self.assertEquals(cache.get("mykey2"), "myvalue2")
+
+    def test_purge(self):
+        cache = client.Cache()
+        cache.set("mykey1", "myvalue1")
+        cache.set("mykey2", "myvalue2")
+        self.assertEquals(cache.get("mykey1"), "myvalue1")
+        self.assertEquals(cache.get("mykey2"), "myvalue2")
+        cache.purge()
+        self.assertEquals(cache.get("mykey1"), None)
+        self.assertEquals(cache.get("mykey2"), None)
 
 
-class ClientRESTAPITestCase(TXSporeTestCase):
+class AspectTestCase(TXSporeTestCase):
+
+    def test_creation(self):
+        someClient = object()
+        aspect = client.Aspect(parent=someClient)
+        self.assertEquals(aspect.parent, someClient)
+
+
+class RESTAspectTestCase(TXSporeTestCase):
 
     def setUp(self):
-        super(ClientRESTAPITestCase, self).setUp()
+        super(RESTAspectTestCase, self).setUp()
+        self.client = client.AsyncClient()
+        self.restAspect = self.client.rest
 
-    def test_getXMLForRest(self):
+    def test_getXMLForREST(self):
 
         def checkForXML(result):
             children = [x.tag for x in result]
@@ -52,37 +78,43 @@ class ClientRESTAPITestCase(TXSporeTestCase):
             self.assertEquals(result.tag, "stats")
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
-        client.getPage = lambda url: succeed(payload.sampleDailyStatsResponse)
+        client.getPage = lambda url: succeed(
+            payload.sampleRESTDailyStatsResponse)
 
-        d = getXMLForREST("http://some.spore.url")
+        d = self.restAspect._getXMLForREST("http://some.spore.url")
         d.addCallback(checkForXML)
         return d
 
     def test_getXMLForRestWithError(self):
-        self.addCleanup(setattr, client, "openURL", client.openURL)
-        client.openURL = lambda url: fail(RuntimeError("oops"))
+        self.addCleanup(setattr, self.client, "openURL", self.client.openURL)
+        self.client.openURL = lambda url: fail(RuntimeError("oops"))
 
-        d = client.getXMLForREST("http://some.spore.url")
+        d = self.restAspect._getXMLForREST("http://some.spore.url")
         self.assertFailure(d, RuntimeError)
         logged = self.catcher.pop()
         self.assertEquals(logged["message"][0], "ERROR: oops")
 
-    def test_getModulesForSubNodes(self):
-        pass
+    def test_getModelsForSubNodes(self):
+        xmlBytes = "<xml><top><child>A</child></top></xml>"
+        xmlTree = util.XML(xmlBytes)
+        models = self.restAspect._getModelsForSubNodes(
+            xmlTree, "top", model.ParsingModel)
+        self.assertEquals(len(models), 1)
+        self.assertEquals(models[0].child, "A")
 
     def test_getDailyStats(self):
 
         def checkModel(model):
-            self.assertEquals(model.totalUploads, 120785568)
-            self.assertEquals(model.dayUploads, 117668)
-            self.assertEquals(model.totalUsers, 3048497)
-            self.assertEquals(model.dayUsers, 1581)
+            self.assertEquals(model.totalUploads, 121325142)
+            self.assertEquals(model.dayUploads, 88683)
+            self.assertEquals(model.totalUsers, 3055769)
+            self.assertEquals(model.dayUsers, 1235)
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleDailyStatsResponse)
+            payload.sampleRESTDailyStatsResponse)
 
-        d = client.getDailyStats()
+        d = self.restAspect.getDailyStats()
         d.addCallback(checkModel)
         return d
 
@@ -97,9 +129,9 @@ class ClientRESTAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleCreatureStatsResponse)
+            payload.sampleRESTCreatureStatsResponse)
 
-        d = client.getStatsForCreature("500327625969")
+        d = self.restAspect.getStatsForCreature("500327625969")
         d.addCallback(checkModel)
         return d
 
@@ -112,9 +144,9 @@ class ClientRESTAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleProfileInfoResponse)
+            payload.sampleRESTProfileInfoResponse)
 
-        d = client.getProfileInfo("oubiwann")
+        d = self.restAspect.getProfileInfo("oubiwann")
         d.addCallback(checkModel)
         return d
 
@@ -132,9 +164,9 @@ class ClientRESTAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleAssetsForUserResponse)
+            payload.sampleRESTAssetsForUserResponse)
 
-        d = client.getAssetsForUser("oubiwann", 0, 4)
+        d = self.restAspect.getAssetsForUser("oubiwann", 0, 4)
         d.addCallback(checkModel)
         return d
 
@@ -149,9 +181,9 @@ class ClientRESTAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleSporeCastsForUserResponse)
+            payload.sampleRESTSporeCastsForUserResponse)
 
-        d = client.getSporeCastsForUser("oubiwann")
+        d = self.restAspect.getSporeCastsForUser("oubiwann")
         d.addCallback(checkModel)
         return d
 
@@ -168,9 +200,9 @@ class ClientRESTAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleAssetsForSporeCastResponse)
+            payload.sampleRESTAssetsForSporeCastResponse)
 
-        d = client.getAssetsForSporeCast("oubiwann", 0, 3)
+        d = self.restAspect.getAssetsForSporeCast("oubiwann", 0, 3)
         d.addCallback(checkModel)
         return d
 
@@ -187,9 +219,9 @@ class ClientRESTAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleAchievementsForUserResponse)
+            payload.sampleRESTAchievementsForUserResponse)
 
-        d = client.getAchievementsForUser("oubiwann", 0, 2)
+        d = self.restAspect.getAchievementsForUser("oubiwann", 0, 2)
         d.addCallback(checkModel)
         return d
 
@@ -203,9 +235,9 @@ class ClientRESTAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleInfoForAssetResponse)
+            payload.sampleRESTInfoForAssetResponse)
 
-        d = client.getInfoForAsset("500327625969")
+        d = self.restAspect.getInfoForAsset("500327625969")
         d.addCallback(checkModel)
         return d
 
@@ -225,9 +257,9 @@ class ClientRESTAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleCommentsForAssetResponse)
+            payload.sampleRESTCommentsForAssetResponse)
 
-        d = client.getCommentsForAsset("500327625969", 0, 2)
+        d = self.restAspect.getCommentsForAsset("500327625969", 0, 2)
         d.addCallback(checkModel)
         return d
 
@@ -242,9 +274,9 @@ class ClientRESTAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleBuddiesForUserResponse)
+            payload.sampleRESTBuddiesForUserResponse)
 
-        d = client.getBuddiesForUser("oubiwann", 0, 2)
+        d = self.restAspect.getBuddiesForUser("oubiwann", 0, 2)
         d.addCallback(checkModel)
         return d
 
@@ -260,17 +292,47 @@ class ClientRESTAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleAssetSearchResponse)
+            payload.sampleRESTAssetSearchResponse)
 
-        d = client.searchAssets("MAXIS_MADE", 0, 4, "CREATURE")
+        d = self.restAspect.searchAssets("MAXIS_MADE", 0, 4, "CREATURE")
         d.addCallback(checkModel)
         return d
 
+    def test_searchAssetsInvalidSearchType(self):
 
-class ClientStaticDataOpenAndFetchTestCase(TXSporeTestCase):
+        self.assertRaises(ValueError, self.restAspect.searchAssets, 
+                          "WRONG_VALUE", 0, 4, "CREATURE")
+        try:
+            self.restAspect.searchAssets( "WRONG_VALUE", 0, 4, "CREATURE")
+        except ValueError, error:
+            self.assertEquals(
+                error.message,
+                ("'WRONG_VALUE' is not one of 'TOP_RATED', 'TOP_RATED_NEW', "
+                 "'NEWEST', 'FEATURED', 'MAXIS_MADE', 'RANDOM', "
+                 "'CUTE_AND_CREEPY'"))
+
+    def test_searchAssetsInvalidAssetType(self):
+
+        self.assertRaises(ValueError, self.restAspect.searchAssets, 
+                          "TOP_RATED", 0, 4, "WRONG_VALUE")
+        try:
+            self.restAspect.searchAssets("TOP_RATED", 0, 4, "WRONG_VALUE")
+        except ValueError, error:
+            self.assertEquals(
+                error.message,
+                ("'WRONG_VALUE' is not one of 'UFO', 'CREATURE', 'BUILDING', "
+                 "'VEHICLE'"))
+
+
+class StaticDataAspectTestCase(TXSporeTestCase):
+
+    def setUp(self):
+        super(StaticDataAspectTestCase, self).setUp()
+        self.client = client.AsyncClient()
+        self.dataAspect = self.client.data
 
     def test_blockingSave(self):
-        filename = client.blockingSave(
+        filename = self.dataAspect._blockingSave(
             "some data", self.tempDirname, self.tempBasename)
         self.assertEquals(filename, "%s/%s" % (
             self.tempDirname, self.tempBasename))
@@ -283,7 +345,7 @@ class ClientStaticDataOpenAndFetchTestCase(TXSporeTestCase):
             self.assertEquals(
                 self.tempFilePath.getContent(), "test payload data")
 
-        d = client.saveFile(
+        d = self.dataAspect._saveFile(
             "test payload data", self.tempDirname, self.tempBasename)
         d.addCallback(checkFileContents)
         return d
@@ -296,7 +358,7 @@ class ClientStaticDataOpenAndFetchTestCase(TXSporeTestCase):
             self.assertEquals(
                 fd.getvalue(), "test payload data")
 
-        d = client.saveToFileDescriptor(
+        d = self.dataAspect._saveToFileDescriptor(
             "test payload data", fd=fd)
         d.addCallback(checkFileContents)
         return d
@@ -308,8 +370,9 @@ class ClientStaticDataOpenAndFetchTestCase(TXSporeTestCase):
         def raiseError(data, path, filename):
             raise IOError("thread oops")
 
-        self.addCleanup(setattr, client, "blockingSave", client.blockingSave)
-        client.blockingSave = raiseError
+        self.addCleanup(setattr, self.dataAspect, "_blockingSave",
+                        self.dataAspect._blockingSave)
+        client._blockingSave = raiseError
         self.addCleanup(setattr, client, "deferToThread", client.deferToThread)
         threadPool = ThreadPool(0, 1)
         threadPool.start()
@@ -320,7 +383,7 @@ class ClientStaticDataOpenAndFetchTestCase(TXSporeTestCase):
             pass
             #import pdb;pdb.set_trace()
 
-        d = client.saveFile("data", "path", "filename")
+        d = self.dataAspect._saveFile("data", "path", "filename")
         d.addErrback(checkError, self.catcher)
         #self.assertFailure(d, IOError)
         #errors = self.flushLoggedErrors(IOError)
@@ -335,12 +398,13 @@ class ClientStaticDataOpenAndFetchTestCase(TXSporeTestCase):
             self.assertEquals(filename, self.tempFilePath.path)
             self.assertEquals(
                 self.tempFilePath.getContent(),
-                "\nsampleLargeCardResponse BINARY DATA")
+                "\nsampleStaticDataLargeCardResponse BINARY DATA")
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
-        client.getPage = lambda url: succeed(payload.sampleLargeCardResponse)
+        client.getPage = lambda url: succeed(
+            payload.sampleStaticDataLargeCardResponse)
 
-        d = client.fetchAndSave(
+        d = self.dataAspect._fetchAndSave(
             "http://some.spore.url", self.tempBasename, self.tempDirname)
         d.addCallback(checkFileContents)
         return d
@@ -351,19 +415,18 @@ class ClientStaticDataOpenAndFetchTestCase(TXSporeTestCase):
 
         def checkFileContents(ignored):
             self.assertEquals(
-                fd.getvalue(), "\nsampleLargeCardResponse BINARY DATA")
+                fd.getvalue(),
+                "\nsampleStaticDataLargeCardResponse BINARY DATA")
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
-        client.getPage = lambda url: succeed(payload.sampleLargeCardResponse)
+        client.getPage = lambda url: succeed(
+            payload.sampleStaticDataLargeCardResponse)
 
-        d = client.fetchAndSave(
+        d = self.dataAspect._fetchAndSave(
             "http://some.spore.url", fd=fd)
         d.addCallback(checkFileContents)
         return d
 
-
-class ClientStaticDataAPITestCase(TXSporeTestCase):
-
     def test_getLargeCard(self):
 
         def checkFileContents(filename, assetID):
@@ -373,13 +436,14 @@ class ClientStaticDataAPITestCase(TXSporeTestCase):
             self.assertEquals(fp.basename(), expectedFilename)
             self.assertEquals(
                 fp.getContent(),
-                "\nsampleLargeCardResponse BINARY DATA")
+                "\nsampleStaticDataLargeCardResponse BINARY DATA")
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
-        client.getPage = lambda url: succeed(payload.sampleLargeCardResponse)
+        client.getPage = lambda url: succeed(
+            payload.sampleStaticDataLargeCardResponse)
 
         assetID = "500327625969"
-        d = client.getLargeCard(assetID, self.tempDirname)
+        d = self.dataAspect.getLargeCard(assetID, self.tempDirname)
         d.addCallback(checkFileContents, assetID)
         return d
 
@@ -398,10 +462,10 @@ class ClientStaticDataAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleAssetDataXMLResponse)
+            payload.sampleStaticDataAssetDataXMLResponse)
 
         assetID = "500327625969"
-        d = client.getAssetDataXML(assetID, self.tempDirname)
+        d = self.dataAspect.getAssetDataXML(assetID, self.tempDirname)
         d.addCallback(checkFileContents, assetID)
         return d
 
@@ -413,14 +477,15 @@ class ClientStaticDataAPITestCase(TXSporeTestCase):
             expectedFilename = "%s_lrg.png" % assetID
             self.assertEquals(fp.basename(), expectedFilename)
             self.assertEquals(
-                fp.getContent(), "\nsampleAssetDataLargePNGResponse BINARY DATA")
+                fp.getContent(),
+                "\nsampleStaticDataAssetDataLargePNGResponse BINARY DATA")
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleAssetDataLargePNGResponse)
+            payload.sampleStaticDataAssetDataLargePNGResponse)
 
         assetID = "500327625969"
-        d = client.getAssetDataLargePNG(assetID, self.tempDirname)
+        d = self.dataAspect.getAssetDataLargePNG(assetID, self.tempDirname)
         d.addCallback(checkFileContents, assetID)
         return d
 
@@ -432,19 +497,37 @@ class ClientStaticDataAPITestCase(TXSporeTestCase):
             expectedFilename = "%s.png" % assetID
             self.assertEquals(fp.basename(), expectedFilename)
             self.assertEquals(
-                fp.getContent(), "\nsampleAssetDataSmallPNGResponse BINARY DATA")
+                fp.getContent(),
+                "\nsampleStaticDataAssetDataSmallPNGResponse BINARY DATA")
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleAssetDataSmallPNGResponse)
+            payload.sampleStaticDataAssetDataSmallPNGResponse)
 
         assetID = "500327625969"
-        d = client.getAssetDataSmallPNG(assetID, self.tempDirname)
+        d = self.dataAspect.getAssetDataSmallPNG(assetID, self.tempDirname)
         d.addCallback(checkFileContents, assetID)
         return d
 
     def test_getAchievementIcon(self):
-        raise SkipTest("Not implemented yet.")
+
+        def checkFileContents(filename, achievmentID):
+            fp = FilePath(filename)
+            self.assertTrue(fp.isfile())
+            expectedFilename = "%s.png" % achievmentID
+            self.assertEquals(fp.basename(), expectedFilename)
+            self.assertEquals(
+                fp.getContent(),
+                "\nsampleStaticDataAchievementIconResponse BINARY DATA")
+
+        self.addCleanup(setattr, client, "getPage", client.getPage)
+        client.getPage = lambda url: succeed(
+            payload.sampleStaticDataAchievementIconResponse)
+
+        achievmentID = "someid"
+        d = self.dataAspect.getAchievementIcon(achievmentID, self.tempDirname)
+        d.addCallback(checkFileContents, achievmentID)
+        return d
 
     def test_getAchievementText(self):
 
@@ -454,17 +537,17 @@ class ClientStaticDataAPITestCase(TXSporeTestCase):
             expectedFilename = "%s.xml" % basename
             self.assertEquals(fp.basename(), expectedFilename)
             xmlTree = util.XML(fp.getContent())
-            achivementsModel = model.RecursiveDataModel(xmlTree)
-            self.assertEquals(len(achivementsModel.achievements), 124)
+            achievementsModel = model.RecursiveDataModel(xmlTree)
+            self.assertEquals(len(achievementsModel.achievements), 124)
             self.assertEquals(
-                achivementsModel.achievements[123].name, "Social")
+                achievementsModel.achievements[123].name, "Social")
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleAchievementDataXMLResponse)
+            payload.sampleStaticDataAchievementDataXMLResponse)
 
         basename = "achievements"
-        d = client.getAchievementDataXML(self.tempDirname)
+        d = self.dataAspect.getAchievementDataXML(self.tempDirname)
         d.addCallback(checkFileContents, basename)
         return d
 
@@ -487,13 +570,25 @@ class ClientStaticDataAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.sampleBuildingBlockMapPartInfoResponse)
+            payload.sampleStaticDataBuildingBlockMapPartInfoResponse)
 
         blockType = "building"
-        d = client.getPartInfo(blockType, self.tempDirname)
+        d = self.dataAspect.getPartInfo(blockType, self.tempDirname)
         d.addCallback(checkFileContents, blockType)
         return d
 
+    def test_getPartInfoInvalidInput(self):
+
+        self.assertRaises(ValueError, self.dataAspect.getPartInfo,
+                                 "something crazy", self.tempDirname)
+        try:
+            self.dataAspect.getPartInfo("something crazy", self.tempDirname)
+        except ValueError, error:
+            self.assertEquals(
+                error.message,
+                ("'something crazy' is not one of 'creature', 'limb', "
+                 "'building', 'vehicle', ''"))
+
     def test_getPartIcon(self):
 
         def checkFileContents(filename, assetID):
@@ -502,14 +597,15 @@ class ClientStaticDataAPITestCase(TXSporeTestCase):
             expectedFilename = "%s.png" % assetID
             self.assertEquals(fp.basename(), expectedFilename)
             self.assertEquals(
-                fp.getContent(), "\nsamplePartIconResponse BINARY DATA")
+                fp.getContent(),
+                "\nsampleStaticDataPartIconResponse BINARY DATA")
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.samplePartIconResponse)
+            payload.sampleStaticDataPartIconResponse)
 
         partFilename = "ce_grasper_radial_02"
-        d = client.getPartIcon(partFilename, self.tempDirname)
+        d = self.dataAspect.getPartIcon(partFilename, self.tempDirname)
         d.addCallback(checkFileContents, partFilename)
         return d
 
@@ -530,10 +626,10 @@ class ClientStaticDataAPITestCase(TXSporeTestCase):
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.samplePaintInfoResponse)
+            payload.sampleStaticDataPaintInfoResponse)
 
         basename = "paintmap"
-        d = client.getPaintInfo(self.tempDirname)
+        d = self.dataAspect.getPaintInfo(self.tempDirname)
         d.addCallback(checkFileContents, basename)
         return d
 
@@ -545,15 +641,205 @@ class ClientStaticDataAPITestCase(TXSporeTestCase):
             expectedFilename = "%s.png" % assetID
             self.assertEquals(fp.basename(), expectedFilename)
             self.assertEquals(
-                fp.getContent(), "\nsamplePaintIconResponse BINARY DATA")
+                fp.getContent(),
+                "\nsampleStaticDataPaintIconResponse BINARY DATA")
 
         self.addCleanup(setattr, client, "getPage", client.getPage)
         client.getPage = lambda url: succeed(
-            payload.samplePaintIconResponse)
+            payload.sampleStaticDataPaintIconResponse)
 
         partFilename = "ce_grasper_radial_02"
-        d = client.getPaintIcon(partFilename, self.tempDirname)
+        d = self.dataAspect.getPaintIcon(partFilename, self.tempDirname)
         d.addCallback(checkFileContents, partFilename)
         return d
 
 
+class AtomAspectTestCase(TXSporeTestCase):
+
+    def setUp(self):
+        super(AtomAspectTestCase, self).setUp()
+        self.client = client.AsyncClient()
+        self.atomAspect = self.client.atom
+
+    def test_getXMLForAtom(self):
+
+        def checkForXML(result):
+            children = [util.scrubXMLNameSpace(x.tag) for x in result]
+            expected = ["id", "title", "updated", "link", "entry", "entry"]
+            self.assertEquals(children, expected)
+            self.assertEquals(util.scrubXMLNameSpace(result.tag), "feed")
+
+        self.addCleanup(setattr, client, "getPage", client.getPage)
+        client.getPage = lambda url: succeed(
+            payload.sampleAtomEventsForAssetResponse)
+
+        d = self.atomAspect._getXMLForAtom("http://some.spore.url")
+        d.addCallback(checkForXML)
+        return d
+
+    def test_getAssetsForUser(self):
+
+        def checkModel(atomModel):
+            self.assertEquals(atomModel.title, "oubiwann")
+            self.assertEquals(atomModel.updated,
+                datetime(2009, 9, 11, 2, 15, 46))
+            self.assertEquals(atomModel.link.href,
+                "http://www.spore.com/atom/user/2263046854")
+            self.assertEquals(len(atomModel.entries), 349)
+
+        self.addCleanup(setattr, client, "getPage", client.getPage)
+        client.getPage = lambda url: succeed(
+            payload.sampleAtomAssetsForUserResponse)
+
+        d = self.atomAspect.getAssetsForUser("oubiwann")
+        d.addCallback(checkModel)
+        return d
+
+    def test_getEventsForUser(self):
+
+        def checkModel(atomModel):
+            self.assertEquals(atomModel.title, "Spore Event Feed")
+            self.assertEquals(atomModel.updated,
+                datetime(2009, 9, 16, 6, 19, 40))
+            self.assertEquals(atomModel.link.href,
+                "http://www.spore.comnull/atom/communityEvent/null")
+            self.assertEquals(len(atomModel.entries), 20)
+
+        self.addCleanup(setattr, client, "getPage", client.getPage)
+        client.getPage = lambda url: succeed(
+            payload.sampleAtomEventsForUserResponse)
+
+        d = self.atomAspect.getEventsForUser("oubiwann")
+        d.addCallback(checkModel)
+        return d
+
+    def test_getEventsForAsset(self):
+
+        def checkModel(atomModel):
+            self.assertEquals(atomModel.title, "Spore Event Feed")
+            self.assertEquals(atomModel.updated,
+                datetime(2009, 9, 16, 6, 19, 40))
+            self.assertEquals(atomModel.link.href,
+                "http://www.spore.comnull/atom/communityEvent/null")
+            self.assertEquals(len(atomModel.entries), 2)
+
+        self.addCleanup(setattr, client, "getPage", client.getPage)
+        client.getPage = lambda url: succeed(
+            payload.sampleAtomEventsForAssetResponse)
+
+        d = self.atomAspect.getEventsForAsset("someasset")
+        d.addCallback(checkModel)
+        return d
+
+    def test_getSporeCastFeed(self):
+
+        def checkModel(atomModel):
+            self.assertEquals(atomModel.title, "Nice Guys")
+            self.assertEquals(atomModel.updated,
+                datetime(2009, 6, 29, 14, 33, 22))
+            self.assertEquals(atomModel.link.href,
+                "http://www.spore.com/atom/aggregator/500320272789")
+            self.assertEquals(len(atomModel.entries), 14)
+
+        self.addCleanup(setattr, client, "getPage", client.getPage)
+        client.getPage = lambda url: succeed(
+            payload.sampleAtomSporeCastFeedResponse)
+
+        d = self.atomAspect.getSporeCastFeed("somesporecastid")
+        d.addCallback(checkModel)
+        return d
+
+    def test_searchAssets(self):
+
+        def checkModel(atomModel):
+            self.assertEquals(atomModel.title, "Searched Assets")
+            self.assertEquals(atomModel.updated,
+                datetime(2009, 9, 10, 23, 22, 51))
+            self.assertEquals(atomModel.link.href,
+                "http://www.spore.com/atom/asset/null")
+            self.assertEquals(len(atomModel.entries), 5)
+
+        self.addCleanup(setattr, client, "getPage", client.getPage)
+        client.getPage = lambda url: succeed(
+            payload.sampleAtomAssetSearchResponse)
+
+        d = self.atomAspect.searchAssets("MAXIS_MADE", 0, 5)
+        d.addCallback(checkModel)
+        return d
+
+
+class ClientTestCase(TXSporeTestCase):
+
+    def test_creation(self):
+        asyncClient = AsyncClient()
+        self.assertTrue(isinstance(asyncClient.rest, client.RESTAspect))
+        self.assertTrue(isinstance(asyncClient.data, client.StaticDataAspect))
+        self.assertTrue(isinstance(asyncClient.cache, client.Cache))
+
+    def test_setCache(self):
+        asyncClient = AsyncClient()
+        asyncClient._setCache("some data", "http://a.url/thing")
+        self.assertEquals(
+            asyncClient.cache.get("http://a.url/thing"), "some data")
+
+    def test_openURL(self):
+        self.addCleanup(setattr, client, "getPage", client.getPage)
+        client.getPage = lambda url: succeed(
+            payload.sampleStaticDataLargeCardResponse)
+
+        asyncClient = AsyncClient()
+        d = asyncClient.openURL("http://some.spore.url")
+        d.addCallback(
+            self.assertEquals,
+            "\nsampleStaticDataLargeCardResponse BINARY DATA")
+        return d
+
+    def test_openURLWithError(self):
+        self.addCleanup(setattr, client, "getPage", client.getPage)
+        client.getPage = lambda url: fail(ValueError("oops"))
+
+        def checkLog(ignored):
+            logged = self.catcher.pop()
+            self.assertEquals(logged["message"][0], "ERROR: oops")
+
+        asyncClient = AsyncClient()
+        failure = asyncClient.openURL("http://some.spore.url/")
+        d = self.assertFailure(failure, ValueError)
+        d.addCallback(checkLog)
+        return d
+
+    def test_openURLCached(self):
+        self.addCleanup(setattr, client, "getPage", client.getPage)
+        client.getPage = lambda url: succeed("request 1")
+
+        def checkGetPage2(result2):
+            self.assertEquals(result2, "request 1")
+
+        def checkGetPage1(result1, asyncClient):
+            self.assertEquals(result1, "request 1")
+            client.getPage = lambda url: succeed("request 2")
+            d = asyncClient.openURL("http://some.spore.url/")
+            d.addCallback(checkGetPage2)
+
+        asyncClient = AsyncClient()
+        d = asyncClient.openURL("http://some.spore.url/")
+        d.addCallback(checkGetPage1, asyncClient)
+        return d
+
+    def test_openURLSkipCache(self):
+        self.addCleanup(setattr, client, "getPage", client.getPage)
+        client.getPage = lambda url: succeed("request 1")
+
+        def checkGetPage2(result2):
+            self.assertEquals(result2, "request 2")
+
+        def checkGetPage1(result1, asyncClient):
+            self.assertEquals(result1, "request 1")
+            client.getPage = lambda url: succeed("request 2")
+            d = asyncClient.openURL("http://some.spore.url/", skipCache=True)
+            d.addCallback(checkGetPage2)
+
+        asyncClient = AsyncClient()
+        d = asyncClient.openURL("http://some.spore.url/")
+        d.addCallback(checkGetPage1, asyncClient)
+        return d
