@@ -60,21 +60,21 @@ class DailyStatsTestCase(TestCase):
 
     def setUp(self):
         super(DailyStatsTestCase, self).setUp()
-        self.xmlTree = XML(payload.sampleDailyStatsResponse)
+        self.xmlTree = XML(payload.sampleRESTDailyStatsResponse)
         self.dailyStats = model.DailyStats(self.xmlTree)
 
     def test_creation(self):
-        self.assertEquals(self.dailyStats.totalUploads, 120785568)
-        self.assertEquals(self.dailyStats.dayUploads, 117668)
-        self.assertEquals(self.dailyStats.totalUsers, 3048497)
-        self.assertEquals(self.dailyStats.dayUsers, 1581)
+        self.assertEquals(self.dailyStats.totalUploads, 121325142)
+        self.assertEquals(self.dailyStats.dayUploads, 88683)
+        self.assertEquals(self.dailyStats.totalUsers, 3055769)
+        self.assertEquals(self.dailyStats.dayUsers, 1235)
 
 
 class CreatureStatsTestCase(TestCase):
 
     def setUp(self):
         super(CreatureStatsTestCase, self).setUp()
-        self.xmlTree = XML(payload.sampleCreatureStatsResponse)
+        self.xmlTree = XML(payload.sampleRESTCreatureStatsResponse)
         self.creatureStats = model.CreatureStats(self.xmlTree)
 
     def test_creation(self):
@@ -116,7 +116,7 @@ class UserTestCase(TestCase):
 
     def setUp(self):
         super(UserTestCase, self).setUp()
-        self.xmlTree = XML(payload.sampleProfileInfoResponse)
+        self.xmlTree = XML(payload.sampleRESTProfileInfoResponse)
         self.user = model.User(self.xmlTree)
 
     def test_creation(self):
@@ -134,7 +134,7 @@ class AssetsForUserTestCase(TestCase):
 
     def setUp(self):
         super(AssetsForUserTestCase, self).setUp()
-        parentNode = XML(payload.sampleAssetsForUserResponse)
+        parentNode = XML(payload.sampleRESTAssetsForUserResponse)
         self.xmlNode = parentNode.find("asset")
         self.asset = model.Asset(self.xmlNode)
 
@@ -160,7 +160,7 @@ class SporeCastTestCase(TestCase):
 
     def setUp(self):
         super(SporeCastTestCase, self).setUp()
-        parentNode = XML(payload.sampleSporeCastsForUserResponse)
+        parentNode = XML(payload.sampleRESTSporeCastsForUserResponse)
         self.xmlNode = parentNode.find("sporecast")
         self.sporecast = model.SporeCast(self.xmlNode)
 
@@ -175,7 +175,7 @@ class SporeCastTestCase(TestCase):
             self.sporecast.updated,
             datetime(2009, 7, 1, 15, 10, 50))
         self.assertEquals(self.sporecast.rating, 8.0)
-        self.assertEquals(self.sporecast.subscriptioncount, 65)
+        self.assertEquals(self.sporecast.subscriptioncount, 67)
         self.assertEquals(self.sporecast.tags, [])
         self.assertEquals(self.sporecast.count, 69)
 
@@ -184,7 +184,7 @@ class SporeCastAssetTestCase(TestCase):
 
     def setUp(self):
         super(SporeCastAssetTestCase, self).setUp()
-        parentNode = XML(payload.sampleAssetsForSporeCastResponse)
+        parentNode = XML(payload.sampleRESTAssetsForSporeCastResponse)
         self.xmlNode = parentNode.find("asset")
         self.asset = model.Asset(self.xmlNode)
 
@@ -210,7 +210,7 @@ class AchievementTestCase(TestCase):
 
     def setUp(self):
         super(AchievementTestCase, self).setUp()
-        parentNode = XML(payload.sampleAchievementsForUserResponse)
+        parentNode = XML(payload.sampleRESTAchievementsForUserResponse)
         self.xmlNode = parentNode.find("achievement")
         self.achievement = model.Achievement(self.xmlNode)
 
@@ -225,7 +225,7 @@ class AssetTestCase(TestCase):
 
     def setUp(self):
         super(AssetTestCase, self).setUp()
-        self.xmlNode = XML(payload.sampleInfoForAssetResponse)
+        self.xmlNode = XML(payload.sampleRESTInfoForAssetResponse)
         self.asset = model.AssetInfo(self.xmlNode)
 
     def test_creation(self):
@@ -253,7 +253,7 @@ class CommentTestCase(TestCase):
 
     def setUp(self):
         super(CommentTestCase, self).setUp()
-        parentNode = XML(payload.sampleCommentsForAssetResponse)
+        parentNode = XML(payload.sampleRESTCommentsForAssetResponse)
         self.xmlNode = parentNode.find("comment")
         self.comment = model.Comment(self.xmlNode)
 
@@ -272,7 +272,7 @@ class BuddyTestCase(TestCase):
 
     def setUp(self):
         super(BuddyTestCase, self).setUp()
-        parentNode = XML(payload.sampleBuddiesForUserResponse)
+        parentNode = XML(payload.sampleRESTBuddiesForUserResponse)
         self.xmlNode = parentNode.find("buddy")
         self.asset = model.Buddy(self.xmlNode)
 
@@ -285,7 +285,7 @@ class SearchAssetTestCase(TestCase):
 
     def setUp(self):
         super(SearchAssetTestCase, self).setUp()
-        parentNode = XML(payload.sampleAssetSearchResponse)
+        parentNode = XML(payload.sampleRESTAssetSearchResponse)
         self.xmlNode = parentNode.find("asset")
         self.asset = model.Asset(self.xmlNode)
 
@@ -299,7 +299,7 @@ class SearchAssetTestCase(TestCase):
             self.asset.image,
             "http://www.spore.com/static/image/500/447/216/500447216760_lrg.png")
         self.assertEquals(self.asset.created, datetime(2009, 9, 10, 22, 0, 51))
-        self.assertEquals(self.asset.rating, -1.0)
+        self.assertEquals(self.asset.rating, 1.5000005)
         self.assertEquals(self.asset.type, "CREATURE")
         self.assertEquals(self.asset.subtype, "0x9ea3031a")
         self.assertEquals(self.asset.parent, "")
@@ -311,7 +311,7 @@ class StaticAssetDataTestCase(TestCase):
 
     def setUp(self):
         super(StaticAssetDataTestCase, self).setUp()
-        self.xmlTree = XML(payload.sampleAssetDataXMLResponse)
+        self.xmlTree = XML(payload.sampleStaticDataAssetDataXMLResponse)
         self.assetData = model.RecursiveDataModel(self.xmlTree)
 
     def test_creation(self):
@@ -346,7 +346,7 @@ class AchievementsDataTestCase(TestCase):
 
     def setUp(self):
         super(AchievementsDataTestCase, self).setUp()
-        self.xmlTree = XML(payload.sampleAchievementDataXMLResponse)
+        self.xmlTree = XML(payload.sampleStaticDataAchievementDataXMLResponse)
         self.achivementsData = model.RecursiveDataModel(self.xmlTree)
 
     def test_creation(self):
@@ -373,7 +373,8 @@ class PartInfoTestCase(TestCase):
 
     def setUp(self):
         super(PartInfoTestCase, self).setUp()
-        self.xmlTree = XML(payload.sampleBuildingBlockMapPartInfoResponse)
+        self.xmlTree = XML(
+            payload.sampleStaticDataBuildingBlockMapPartInfoResponse)
         self.partData = model.RecursiveDataModel(self.xmlTree)
 
     def test_creation(self):
@@ -400,7 +401,7 @@ class PaintInfoTestCase(TestCase):
 
     def setUp(self):
         super(PaintInfoTestCase, self).setUp()
-        self.xmlTree = XML(payload.samplePaintInfoResponse)
+        self.xmlTree = XML(payload.sampleStaticDataPaintInfoResponse)
         self.paintData = model.RecursiveDataModel(self.xmlTree)
 
     def test_creation(self):
@@ -417,3 +418,26 @@ class PaintInfoTestCase(TestCase):
             self.paintData.paints[104].filename, "be_concrete_06")
         self.assertEquals(
             self.paintData.paints[104].aestheticTags, ["stucco", "stone"])
+
+
+class AtomDataModelTestCase(TestCase):
+
+    def setUp(self):
+        super(AtomDataModelTestCase, self).setUp()
+        self.xmlTree = XML(payload.sampleAtomAssetsForUserResponse)
+        self.atomData = model.AtomDataModel(self.xmlTree)
+
+    def test_creation(self):
+        self.assertEquals(self.atomData.title, "oubiwann")
+        self.assertEquals(self.atomData.updated,
+            datetime(2009, 9, 11, 2, 15, 46))
+        self.assertEquals(self.atomData.link.href,
+            "http://www.spore.com/atom/user/2263046854")
+        self.assertEquals(len(self.atomData.entries), 349)
+        self.assertEquals(self.atomData.entries[0].title, "Borziadinid")
+        self.assertEquals(self.atomData.entries[0].updated,
+            datetime(2009, 9, 11, 2, 15, 46))
+        self.assertEquals(self.atomData.entries[0].author.name, "oubiwann")
+        self.assertEquals(self.atomData.entries[0].content.type, "html")
+        self.assertEquals(self.atomData.entries[0].content.img.src,
+            "http://static.spore.com/static/thumb/500/447/356/500447356422.png")
